# brawlwiki

- This library is a sync wrapper for [BrawlWiki API](https://ariusx7.github.io/brawlwiki-api/).
- Python 3.6 or later is required.

## Features

- Covers all of the endpoints of the API.
- Access constant values such as attack name, description, etc!
- Easy to use with an object oriented design.
